@@ -48,8 +48,3 @@ class UserFactory(factory.django.DjangoModelFactory):
             is_staff=True,
             password=factory.PostGenerationMethodCall("set_password", USER_PASSWORD),
         )
-        tech = factory.Trait(
-            username="user-tech",
-            profile__is_tech_account=True,
-            password=factory.PostGenerationMethodCall("set_password", USER_PASSWORD),
-        )
